<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       ifelsetech.com
 * @since      1.0.0
 *
 * @package    Its_Price_Breakup
 * @subpackage Its_Price_Breakup/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Its_Price_Breakup
 * @subpackage Its_Price_Breakup/admin
 * @author     ifelse <info@ifelsetech.com>
 */
class Its_Price_Breakup_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 * 
	 */
	 protected $activated;
	public function __construct( $plugin_name, $version, $activated ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		$this->activated = $activated;


	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Its_Price_Breakup_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Its_Price_Breakup_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
			wp_enqueue_style("its-pb-bootstrap", 'https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/css/bootstrap.min.css', array(), $this->version, 'all');

		wp_enqueue_style( $this->plugin_name, ITS_PRICE_BREAKUP_PATH . 'css/its-price-breakup-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Its_Price_Breakup_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Its_Price_Breakup_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
			wp_enqueue_script('its-bp-bootstrap', 'https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js', array('jquery'), $this->version, false);

		wp_enqueue_script( $this->plugin_name, ITS_PRICE_BREAKUP_PATH . 'js/its-price-breakup-admin.js', array( 'jquery' ), $this->version, false );

	}

	public function its_pb_admin_menu(){
	   // add_menu_page("ITS Price Breakup", "ITS Price Breakup", "edit_others_shop_orders", "its-price-breakup", array($this, "its_pb_activate_license"), "dashicons-screenoptions", 22);
		add_submenu_page("its-jewellery-price", "ITS Price Breakup", "ITS Price Breakup", "manage_woocommerce", "price-breakup", array($this, "its_pb_activate_license"));

	}
	public function its_pb_activate_license(){

		ob_start();
		require_once(ITS_PRICE_BREAKUP_PATH . "admin/partials/its-price-breakup-admin-display.php");
	    ob_get_contents();
	   
	
	}

}
