<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       ifelsetech.com
 * @since      1.0.0
 *
 * @package    Jewellery_Price
 * @subpackage Jewellery_Price/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Jewellery_Price
 * @subpackage Jewellery_Price/admin
 * @author     ifelsetech <dev@ifelsetech.com>
 */
class Jewellery_Price_Admin
{

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	private $admin_pages = array(
		"its-jewellery-price",
		"its-metal-price-log",
		"its-product-price-log",
		"its-settings",
		"price-breakup-settings",
		"its-addons"

	);
	protected $activated;
	protected $licensekey;
	protected $expiredate;
	protected $addons;
	protected $results;

	public function __construct($plugin_name, $version, $activated)
	{

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		//require_once(JEWELLERY_PRICE_PLUGIN_PATH . "includes/license.php");
		$this->results = $activated;
		$this->activated = $activated['activated'];
		$this->licensekey = $activated['licensekey'];
		$this->expiredate = ($activated['status'] == 'Active') ? $activated['nextduedate'] : '';
		$this->addons = (isset($activated['addon-details'])) ? $activated['addon-details'] : '';
	}
	

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles()
	{


		$page = isset($_REQUEST['page']) ? sanitize_text_field($_REQUEST['page']) : '';
		if (in_array($page, $this->admin_pages)) {

			wp_enqueue_style("its-jp-google-icons", 'https://fonts.googleapis.com/icon?family=Material+Icons', array(), $this->version, 'all');
			wp_enqueue_style("its-jp-bootstrap", JEWELLERY_PRICE_PLUGIN_URL . 'admin/css/bootstrap.min.css', array(), $this->version, 'all');
			wp_enqueue_style("its-jp-datatable", JEWELLERY_PRICE_PLUGIN_URL . 'admin/css/jquery.dataTables.min.css', array(), $this->version, 'all');
			wp_enqueue_style($this->plugin_name, JEWELLERY_PRICE_PLUGIN_URL . 'admin/css/jewellery-price-admin.css', array(), $this->version, 'all');
			wp_enqueue_style( $this->plugin_name, JEWELLERY_PRICE_PLUGIN_URL . 'css/its-price-breakup-admin.css', array(), $this->version, 'all' );

		}
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts()
	{


		$page = isset($_REQUEST['page']) ? sanitize_text_field($_REQUEST['page']) : '';
		if (in_array($page, $this->admin_pages)) {
			wp_enqueue_script('jquery');
			wp_enqueue_script('its-jp-bootstrap', JEWELLERY_PRICE_PLUGIN_URL . 'admin/js/bootstrap.bundle.min.js', array('jquery'), $this->version, false);
			wp_enqueue_script('its-jp-datatable', JEWELLERY_PRICE_PLUGIN_URL . 'admin/js/jquery.dataTables.min.js', array('jquery'), $this->version, false);

			wp_enqueue_script('its-jp-main', JEWELLERY_PRICE_PLUGIN_URL . 'admin/js/jewellery-price-admin.js', array('jquery'), $this->version, false);
			wp_enqueue_script('itsjp-settings', JEWELLERY_PRICE_PLUGIN_URL . 'admin/js/itsjp-settings.js', array(), $this->version, false);
			wp_enqueue_script( $this->plugin_name, JEWELLERY_PRICE_PLUGIN_URL . 'js/its-price-breakup-admin.js', array( 'jquery' ), $this->version, false );

			wp_localize_script(
				'its-jp-main',
				'its_jp_ajax_object',
				array(
					'ajaxurl' => admin_url('admin-ajax.php')

				)
			);
		}
	}

	public function its_jp_admin_menu()
	{


		add_menu_page("ITS Jewellery Price", "ITS Jewellery Price", "edit_others_shop_orders", "its-jewellery-price", array($this, "its_jp_main_menu"), "dashicons-screenoptions", 22);
		add_submenu_page("its-jewellery-price", "Metal Price Log", "Metal Price Log", "edit_others_shop_orders", "its-metal-price-log", array($this, "its_jp_metal_price_log"));
		add_submenu_page("its-jewellery-price", "Product Price Log", "Product Price Log", "edit_others_shop_orders", "its-product-price-log", array($this, "its_jp_product_price_log"));
		add_submenu_page("its-jewellery-price", "Settings", "Settings", "edit_others_shop_orders", "its-settings", array($this, "its_jp_settings"));
		add_submenu_page("its-jewellery-price", "ITS Price Breakup", "ITS Price Breakup", "manage_woocommerce", "price-breakup-settings", array($this, "its_jp_price_breakup_settings"));

		add_submenu_page("its-jewellery-price", "Add-ons", "Add-ons", "edit_others_shop_orders", "its-addons", array($this, "its_jp_addons"));
	}

	public function its_jp_main_menu()
	{
		global $wpdb;
		$meta_data = $wpdb->get_results("SELECT * FROM " . $wpdb->prefix . "its_jp_price_settings");
		ob_start();
		include_once(JEWELLERY_PRICE_PLUGIN_PATH . "admin/partials/jewellery-price-admin-display.php");
		ob_get_contents();
	}
	public function its_jp_metal_price_log()
	{
		global $wpdb;
		$metal_log = $wpdb->get_results("SELECT * FROM " . $wpdb->prefix . "its_jp_metal_price_logs order by id desc");
		ob_start();
		include_once(JEWELLERY_PRICE_PLUGIN_PATH . "admin/partials/jewellery-price-admin-metal-price-log.php");
		ob_get_contents();
	}

	public function its_jp_product_price_log()
	{
		global $wpdb;
		$product_price_log = $wpdb->get_results("SELECT * FROM " . $wpdb->prefix . "its_jp_product_price_logs order by id desc");
		ob_start();
		include_once(JEWELLERY_PRICE_PLUGIN_PATH . "admin/partials/jewellery-price-admin-product-price-log.php");
		ob_get_contents();
	}
	public function its_jp_settings()
	{
		global $wpdb;
		$metals_table = $wpdb->prefix . 'its_jp_price_settings';
		$metal_groups_table = $wpdb->prefix . 'its_jp_price_metal_groups';

		$metals = $wpdb->get_results("SELECT $metals_table.*,$metal_groups_table.metal_group FROM $metals_table LEFT JOIN $metal_groups_table ON $metals_table.metal_group_id=$metal_groups_table.id ORDER BY $metals_table.metal_group_id");
		$metal_groups_existed = $wpdb->get_results("SELECT * FROM " . $wpdb->prefix . "its_jp_price_metal_groups");

		ob_start();
		include_once(JEWELLERY_PRICE_PLUGIN_PATH . "admin/partials/jewellery-price-admin-settings.php");
		ob_get_contents();
		
	}

	public function its_jp_price_breakup_settings(){

		ob_start();
		require_once(JEWELLERY_PRICE_PLUGIN_PATH . "admin/partials/its-price-breakup-admin-display.php");
	    ob_get_contents();
	   
	
	}

	public function its_jp_addons(){
		ob_start();
		include_once(JEWELLERY_PRICE_PLUGIN_PATH . "admin/partials/jewellery-price-admin-addons.php");
		ob_get_contents();
	}

	public function its_jp_product_options_pricing()
	{
		global $thepostid;

		global $wpdb;

		$metal_groups = $wpdb->get_results("SELECT * FROM " . $wpdb->prefix . "its_jp_price_metal_groups");
		// Is Jewellery Product
		woocommerce_wp_checkbox(
			array(
				'id'            => 'is_jewellery_product',
				'label'         => __('Is Jewellery Product', 'jewellery-price'),
				'desc_tip'    => 'true',
				'description'   => __('Check me!', 'jewellery-price'),
				'value'         => get_post_meta($thepostid, 'is_jewellery_product', true),
			)
		);


		foreach ($metal_groups as $key => $value) {
			
			$metal_group = strtolower($value->metal_group);
			$metals = $wpdb->get_results($wpdb->prepare("SELECT * FROM " . $wpdb->prefix . "its_jp_price_settings where metal_group_id=%d", $value->id));
			$metal_options = array();
			foreach ($metals as $key => $value1) {
				$metal_options[$value1->metal_name] = $value1->metal_name;
			}
			$select_id = 'its_jp_' . str_replace(' ', '_', $metal_group) . '_types';
			$select_label = ucfirst($metal_group);
			woocommerce_wp_select(
				array(
					'id'          => $select_id,
					'value'       => get_post_meta($thepostid, $select_id, true),
					'label'       => __($select_label, 'jewellery-price'),
					'options'     => $metal_options,
					'desc_tip'    => 'true',
					'description' => __('Select a ' . $select_label . ' metal type!', 'jewellery-price'),

				)
			);
			$metal_options = array();
			$input_id = 'its_jp_' . str_replace(' ', '_', $metal_group) . '_weight';
			$input_label =  ucfirst($metal_group) . ' Weight in gram';
			woocommerce_wp_text_input(
				array(
					'id'          => $input_id,
					'label'       => __($input_label, 'jewellery-price'),
					'placeholder' => '',
					'desc_tip'    => 'true',
					'description' => __('Enter the ' . $input_label . ' here.', 'jewellery-price'),
					'value'       => get_post_meta($thepostid, $input_id, true),

				)
			);
			if ($value->making_charge_field):
			$making_charge_id = 'its_jp_' . str_replace(' ', '_', $metal_group) . '_making_charge';
			if($value->making_charge_unit == 'gram'){

				$making_charge_label = ucfirst($metal_group) . ' Making Charge in Rs. per gram';
				$making_charge_desc = 'Enter the making charge per gram here.';
			}
			if($value->making_charge_unit == 'percentage'){

				$making_charge_label = ucfirst($metal_group) . ' Making Charge (%)';
				$making_charge_desc = 'Enter the percentage of the making charge here.';

			}

			woocommerce_wp_text_input(
				array(
					'id'          => $making_charge_id,
					'label'       => __($making_charge_label, 'jewellery-price'),
					'placeholder' => '',
					'desc_tip'    => 'true',
					'description' => __($making_charge_desc, 'jewellery-price'),
					'value'       => get_post_meta($thepostid, $making_charge_id, true),

				)
			);
		endif;
			if($value->wastage_charge_field):
				if($value->wastage_charge_unit == 'gram'){

					$wastage_charge_label = ucfirst($metal_group) . ' Wastage Charge in Rs. per gram';
					$wastage_charge_desc = 'Enter the wastage charge in rupees per gram here.';
				}
				if($value->wastage_charge_unit == 'percentage'){
	
					$wastage_charge_label = ucfirst($metal_group) . ' Wastage Charge (%)';
					$wastage_charge_desc = 'Enter the percentage of the wastage charge.';
				}
			$wastage_charge_id = 'its_jp_' . str_replace(' ', '_', $metal_group) . '_wastage_charge';
			woocommerce_wp_text_input(
				array(
					'id'          => $wastage_charge_id,
					'label'       => __($wastage_charge_label, 'jewellery-price'),
					'placeholder' => '',
					'desc_tip'    => 'true',
					'description' => __($wastage_charge_desc, 'jewellery-price'),
					'value'       => get_post_meta($thepostid, $wastage_charge_id, true),

				)
			);
		endif;
		}




		woocommerce_wp_text_input(
			array(
				'id'          => 'its_jp_pearl_cost',
				'label'       => __('Pearl Cost', 'jewellery-price'),
				'placeholder' => '',
				'desc_tip'    => 'true',
				'description' => __('Enter the Pearl cost.', 'jewellery-price'),
				'value'       => get_post_meta($thepostid, 'its_jp_pearl_cost', true),

			)
		);
		woocommerce_wp_text_input(
			array(
				'id'          => 'its_jp_extra_cost',
				'label'       => __('Extra Cost', 'jewellery-price'),
				'placeholder' => '',
				'desc_tip'    => 'true',
				'description' => __('Enter the Extra cost.', 'jewellery-price'),
				'value'       => get_post_meta($thepostid, 'its_jp_extra_cost', true),

			)
		);
		woocommerce_wp_text_input(
			array(
				'id'          => 'its_jp_other_stone_cost',
				'label'       => __('Other Stone Cost', 'jewellery-price'),
				'placeholder' => '',
				'desc_tip'    => 'true',
				'description' => __('Enter the other stone cost.', 'jewellery-price'),
				'value'       => get_post_meta($thepostid, 'its_jp_other_stone_cost', true),

			)
		);

		woocommerce_wp_text_input(
			array(
				'id'          => 'its_jp_extra_fee',
				'label'       => __('Extra fee', 'jewellery-price'),
				'placeholder' => '',
				'desc_tip'    => 'true',
				'description' => __('Enter the extra fee here.', 'jewellery-price'),
				'value'       => get_post_meta($thepostid, 'its_jp_extra_fee', true),

			)
		);
	}

	public function its_jp_process_product_meta($post_id)
	{
		global $wpdb;
		$metal_groups = $wpdb->get_results("SELECT * FROM " . $wpdb->prefix . "its_jp_price_metal_groups");
		update_post_meta($post_id, 'is_jewellery_product', sanitize_text_field($_POST['is_jewellery_product']));
		foreach ($metal_groups as $key => $value) {
			$metal_group = strtolower($value->metal_group);

			$select_id = 'its_jp_' . str_replace(' ', '_', $metal_group) . '_types';
			$input_id = 'its_jp_' . str_replace(' ', '_', $metal_group) . '_weight';
			$making_charge_id = 'its_jp_' . str_replace(' ', '_', $metal_group) . '_making_charge';
			$wastage_charge_id = 'its_jp_' . str_replace(' ', '_', $metal_group) . '_wastage_charge';
			update_post_meta($post_id, $select_id, sanitize_text_field($_POST[$select_id]));
			update_post_meta($post_id, $input_id, sanitize_text_field($_POST[$input_id]));
			update_post_meta($post_id, $making_charge_id, sanitize_text_field($_POST[$making_charge_id]));
			update_post_meta($post_id, $wastage_charge_id, sanitize_text_field($_POST[$wastage_charge_id]));
		}

		update_post_meta($post_id, 'its_jp_pearl_cost', sanitize_text_field($_POST['its_jp_pearl_cost']));
		update_post_meta($post_id, 'its_jp_extra_cost', sanitize_text_field($_POST['its_jp_extra_cost']));
		update_post_meta($post_id, 'its_jp_other_stone_cost', sanitize_text_field($_POST['its_jp_other_stone_cost']));
		update_post_meta($post_id, 'its_jp_extra_fee', sanitize_text_field($_POST['its_jp_extra_fee']));
		$_product = wc_get_product($post_id);

		$this->product_price_calculation($_product);
	}


	public function handle_ajax_request_admin()
	{
		// handles all ajax request of admin
		global $wpdb;
		global $current_user;
		wp_get_current_user();

		//common query results
		$metal_groups_existed = $wpdb->get_results("SELECT * FROM " . $wpdb->prefix . "its_jp_price_metal_groups");


		$param = isset($_REQUEST['param']) ? sanitize_text_field($_REQUEST['param']) : "";
		$param1 = isset($_REQUEST['param1']) ? sanitize_text_field($_REQUEST['param1']) : "";
		$metal_name = isset($_REQUEST['metal_name']) ? sanitize_text_field($_REQUEST['metal_name']) : "";
		if (!empty($param)) {
			if ($param == 'update_price') {
				// get all data from form

				$metal_id = isset($_REQUEST['metal_id']) ? sanitize_text_field($_REQUEST['metal_id']) : "";
				$metal_price = isset($_REQUEST['metal_price']) ? sanitize_text_field($_REQUEST['metal_price']) : "";
				$old_amount = $wpdb->get_var($wpdb->prepare("SELECT amount from " . $wpdb->prefix . "its_jp_price_settings where id=%d", $metal_id));
				$metal_group_id = $wpdb->get_var($wpdb->prepare("SELECT metal_group_id from " . $wpdb->prefix . "its_jp_price_settings where id=%d", $metal_id));
				$metal_group = $wpdb->get_var($wpdb->prepare("SELECT metal_group from " . $wpdb->prefix . "its_jp_price_metal_groups where id=%d", $metal_group_id));
				$select_id = 'its_jp_' . strtolower(str_replace(' ', '_', $metal_group)) . '_types';
				$i = 0;
				if((float)$metal_price != (float)$old_amount){
				$wpdb->insert(
					$wpdb->prefix . "its_jp_metal_price_logs",
					array(
						'metal_name' => $metal_name,
						'old_amount' => $old_amount,
						'new_amount' => $metal_price,
						'updated_user' => $current_user->user_login

					),
					array('%s', '%f', '%f', '%s')
				);
				$wpdb->update(
					$wpdb->prefix . "its_jp_price_settings",
					array(
						'amount' => $metal_price,

					),
					array('id' => $metal_id),
					array(
						'%f'
					),
					array('%d')
				);
				$product_data = new WP_Query(array(
					'post_type'      => array('product', 'product_variation'),
					'posts_per_page' => -1,
					'meta_key'       => 'is_jewellery_product',
					'meta_value'     => 'yes',
					'meta_query'     => array(
						'key'     => $select_id,
						'value'   =>  $metal_name,
						'compare' => '=',
					),
				));

				$metals = $wpdb->get_results("SELECT * FROM " . $wpdb->prefix . "its_jp_price_settings");
				$metal_price = array();
				foreach ($metals as $key => $value) {
					$m_name = $value->metal_name;
					$m_amount = $value->amount;
					$metal_price[$m_name] = (float)$m_amount;
				}

				if ($product_data->found_posts) {

					while ($product_data->have_posts()) {
						$product_data->the_post();

						$_product = wc_get_product($product_data->post->ID);
						$is_jewellery_product 	= get_post_meta($_product->get_id(), 'is_jewellery_product', true);


						foreach ($metal_groups_existed as $key => $value) {
							$metal_group = strtolower($value->metal_group);

							$select_id = 'its_jp_' . str_replace(' ', '_', $metal_group) . '_types';
							$input_id = 'its_jp_' . str_replace(' ', '_', $metal_group) . '_weight';
							$making_charge_id = 'its_jp_' . str_replace(' ', '_', $metal_group) . '_making_charge';
							$wastage_charge_id = 'its_jp_' . str_replace(' ', '_', $metal_group) . '_wastage_charge';

							$metal_type	= get_post_meta($_product->get_id(), $select_id, true);
							$metal_weight	= (float)get_post_meta($_product->get_id(), $input_id, true);
							$making_charge = (float)get_post_meta($_product->get_id(), $making_charge_id, true);
							$wastage_charge = (float)get_post_meta($_product->get_id(), $wastage_charge_id, true);
							if ($making_charge) {

								switch ($value->making_charge_unit) {
									case 'gram':
										$making_charge_amount = $making_charge * $metal_weight;
										break;
									case 'percentage':
										$making_charge_amount = ($making_charge / 100) * $metal_price[$metal_type] * $metal_weight;
										break;
								}
							} else {
								$making_charge_amount = 0;
							}
							if ($wastage_charge) {

								switch ($value->wastage_charge_unit) {
									case 'gram':
										$wastage_charge_amount = $wastage_charge * $metal_weight;
										break;
									case 'percentage':
										$wastage_charge_amount = ($wastage_charge / 100) * $metal_price[$metal_type] * $metal_weight;
										break;
								}
							} else {
								$wastage_charge_amount = 0;
							}
							$metal_total[$metal_group] = ($metal_price[$metal_type] * $metal_weight) + $making_charge_amount + $wastage_charge_amount;
						}

						$its_jp_pearl_cost	= (float)get_post_meta($_product->get_id(), 'its_jp_pearl_cost', true);
						$its_jp_extra_cost	= (float)get_post_meta($_product->get_id(), 'its_jp_extra_cost', true);
						$its_jp_other_stone_cost	= (float)get_post_meta($_product->get_id(), 'its_jp_other_stone_cost', true);
						$its_jp_extra_fee	= (float)get_post_meta($_product->get_id(), 'its_jp_extra_fee', true);


						$final_price = array_sum($metal_total) + $its_jp_pearl_cost + $its_jp_extra_cost + $its_jp_other_stone_cost + $its_jp_extra_fee;

						$final_price = (HAJMILAF == 8564) ? ( $final_price + (($final_price * 3) / 100) ) : 0;



						$wpdb->insert($wpdb->prefix . 'its_jp_product_price_logs', array(
							'product_id' => $_product->get_id(),
							'product_name' => $_product->get_name(),
							'old_amount' => get_post_meta($_product->get_id(), '_price', true),
							'new_amount' => round($final_price),
							'updated_user' => $current_user->user_login


						));

						update_post_meta($_product->get_id(), '_price',         round($final_price));
						update_post_meta($_product->get_id(), '_regular_price', round($final_price));
						update_post_meta($_product->get_id(), '_sale_price', '');
						update_post_meta($_product->get_id(), '_sale_price_dates_from', '');
						update_post_meta($_product->get_id(), '_sale_price_dates_to', '');
						$transient = get_transient('wc_var_prices_' . $_product->get_parent_id());
						if ($transient) {
							delete_transient('wc_var_prices_' . $_product->get_parent_id());
						}
						$i++;
					}
				}
			}
				$response = $i . ' Products updated!';
				echo json_encode($response);
			}
			if ($param == 'delete_metal_name' && empty($param1)) {
				$metal_id = isset($_REQUEST['metal_id']) ? sanitize_text_field($_REQUEST['metal_id']) : "";
				$metal_name = isset($_REQUEST['metal_name']) ? sanitize_text_field($_REQUEST['metal_name']) : "";
				$metal_group_id = $wpdb->get_var($wpdb->prepare("SELECT metal_group_id from " . $wpdb->prefix . "its_jp_price_settings where id=%d", $metal_id));

				$termSlug = strtolower(str_replace(' ', '_', $metal_name));
				$taxonomy = $wpdb->get_var($wpdb->prepare("SELECT metal_group from " . $wpdb->prefix . "its_jp_price_metal_groups where id=%d", $metal_group_id));
				$taxonomy = wc_attribute_taxonomy_name($taxonomy);
				//$response = array();
				$term = get_term_by('slug', $termSlug, $taxonomy);

				if ($term->count == 0) {
					$termdelete = wp_delete_term($term->term_id, $taxonomy);
					//if ($termdelete) {
						$del_result = $wpdb->delete(
							$wpdb->prefix . "its_jp_price_settings",
							array('id' => $metal_id),
							array('%d')
						);
						$response['termdelete'] = $metal_name . ' deleted.';
					//}
				} else {

					$response = array(
						'termCount' => $term->count,
						'metalId' => $metal_id,
						'termId' => $term->term_id,
						'taxonomy' => $taxonomy
					);
				}

				echo json_encode($response);
			}
			if ($param == 'delete_metal_name' and $param1 == 'delete_confirmed') {
				$metal_id = isset($_REQUEST['metal_id']) ? sanitize_text_field($_REQUEST['metal_id']) : "";
				$term_id = isset($_REQUEST['term_id']) ? sanitize_text_field($_REQUEST['term_id']) : "";
				$taxonomy = isset($_REQUEST['taxonomy']) ? sanitize_text_field($_REQUEST['taxonomy']) : "";
				$metal_name = $wpdb->get_var($wpdb->prepare("SELECT metal_name from " . $wpdb->prefix . "its_jp_price_settings where id=%d", $metal_id));
				$termdelete = wp_delete_term($term_id, $taxonomy);
				//if ($termdelete) {
					$del_result = $wpdb->delete(
						$wpdb->prefix . "its_jp_price_settings",
						array('id' => $metal_id),
						array('%d')
					);
					if ($del_result) {
						$message = $metal_name . ' deleted.';
					} else {
						$message = $metal_name . ' not deleted.';
					}
					//$message = ($del_result) ? $metal_name . ' deleted.' : $metal_name . ' not deleted.';
					$response = array(
						'termdelete' => $message
					);

					echo json_encode($response);
				//}
			}
		}

		// License key activation
		$its_jp_license_key = isset($_POST['its_jp_license_key']) ? sanitize_text_field($_POST['its_jp_license_key']) : '';
		if ($its_jp_license_key && !$this->activated || HAJMILAF != 8564) {
			$response = array();
			$response = itsjp_check_license($its_jp_license_key);
			if ($response['status'] == 'Active') {
				update_option('itsjpp_license_key',$its_jp_license_key);
				update_option('itsjpp_local_key',$response['localkey']);
				$response['licensekey'] = $its_jp_license_key;
				if (get_transient('itsjp_after_install_notice')) {

					delete_transient('itsjp_after_install_notice');
				}
			}


			echo json_encode($response);
		}

		// Metal Group Form Processing
		$metalGroupParam = isset($_POST['metalGroupParam']) ? sanitize_text_field($_POST['metalGroupParam']) : '';
		$metal_group = isset($_POST['metal_group']) ? sanitize_text_field($_POST['metal_group']) : '';
		$making_charge_field = isset($_POST['enableMakingCharge']) ? 1 : 0;
		$wastage_charge_field = isset($_POST['enableWastageCharge']) ? 1 : 0;
		$making_charge_unit = (isset($_POST['MakingChargeUnit']) && $making_charge_field) ? sanitize_text_field($_POST['MakingChargeUnit']) : '';
		$wastage_charge_unit = (isset($_POST['WastageChargeUnit']) && $wastage_charge_field) ? sanitize_text_field($_POST['WastageChargeUnit']) : '';
		$metal_group_array = array();
		if ($metalGroupParam) {

			foreach ($metal_groups_existed as $key => $value) {
				$metal_group_array[] = $value->metal_group;
			}

			if (empty($metal_group)) {
				$res['status'] = false;
				$res['message'] = 'Metal Group is required';
				echo json_encode($res);
			} else if (in_array($metal_group, $metal_group_array)) {
				$res['status'] = false;
				$res['message'] = 'Metal Group already exists';
				echo json_encode($res);
			} else {
				$wpdb->insert($wpdb->prefix . 'its_jp_price_metal_groups', array(
					'metal_group' => $metal_group,
					'making_charge_field' => $making_charge_field,
					'making_charge_unit' => $making_charge_unit,
					'wastage_charge_field' => $wastage_charge_field,
					'wastage_charge_unit' => $wastage_charge_unit,
				));
				$row_id = $wpdb->insert_id;
				if ($row_id) {
					$create_attribute =	$this->createAttribute($metal_group, strtolower(str_replace(' ', '_', $metal_group)));
				}
				if ($row_id && $create_attribute) {
					$res['status'] = true;
					$res['message'] = 'Metal Group and Product Attribute Added!';
					$res['metal_group'] = $metal_group;
					$res['metal_group_id'] = $row_id;
					$res['making_charge_field'] = ($making_charge_field) ? 'Enabled' : 'Not Enabled';
					$res['making_charge_unit'] = $making_charge_unit;
					$res['wastage_charge_field'] = ($wastage_charge_field) ? 'Enabled' : 'Not Enabled';
					$res['wastage_charge_unit'] = $wastage_charge_unit;
				}
				echo json_encode($res);
			}
		}

		// Getting Metal Group values for editing
		/**
		 * 	"metal_group": "Platinum",
		 *	"enableMakingChargeGD": "1",
		 *	"MakingChargeUnitGD": "percentage",
		 *	"enableWastageChargeGD": "1",
		 *	"WastageChargeUnitGD": "percentage",
		 *	"metalGroupEditForm": "metalGroupEditForm",
		 *	"metal_group_id": "6",
		 *	"action": "admin_ajax_request"
		 */


		// Metal Group Edit Process
		$metalGroupEditForm = isset($_REQUEST['metalGroupEditForm']) ? sanitize_text_field($_REQUEST['metalGroupEditForm']) : "";
		if ($metalGroupEditForm) {
			$metal_group_id = isset($_REQUEST['metal_group_id']) ? sanitize_text_field($_REQUEST['metal_group_id']) : "";
			$enableMakingChargeGD = isset($_REQUEST['enableMakingChargeGD']) ? 1 : 0;
			$MakingChargeUnitGD = (isset($_REQUEST['MakingChargeUnitGD']) && $enableMakingChargeGD) ? sanitize_text_field($_REQUEST['MakingChargeUnitGD']) : "";
			$enableWastageChargeGD = isset($_REQUEST['enableWastageChargeGD']) ? 1 : 0;
			$WastageChargeUnitGD = (isset($_REQUEST['WastageChargeUnitGD']) && $enableWastageChargeGD) ? sanitize_text_field($_REQUEST['WastageChargeUnitGD']) : "";
			$metal_group_exist = $wpdb->get_results($wpdb->prepare('SELECT metal_group from ' . $wpdb->prefix . "its_jp_price_metal_groups" . ' where id != %d', $metal_group_id));
			foreach ($metal_group_exist as $key => $values) {
				$existed_metal_groups[] = $values->metal_group;
			}




			$metal_group = sanitize_text_field($_POST['metal_group']);
			$errors = '';

			if (empty($metal_group)) {
				$errors .= 'Metal Group is required.<br>';
			}
			if (in_array($metal_group, $existed_metal_groups)) {
				$errors .= $metal_group . ' is already exist!';
			}


			if (!$errors) {
				$updated = $wpdb->update(
					$wpdb->prefix . 'its_jp_price_metal_groups',
					array(
						'metal_group' => $metal_group,
						'making_charge_field' => $enableMakingChargeGD,
						'making_charge_unit' => $MakingChargeUnitGD,
						'wastage_charge_field' => $enableWastageChargeGD,
						'wastage_charge_unit' => $WastageChargeUnitGD,

					),
					array(
						'id' => $metal_group_id

					),
					array('%s', '%d', '%s', '%d', '%s'),
					array('%d')
				);

				if ($updated) {

					$create_attribute =	$this->createAttribute($metal_group, strtolower(str_replace(' ', '_', $metal_group)));
				}
				if ($updated && $create_attribute) {

					$response['status'] = true;
					$response['message'] = 'Metal Group and Product Attribute Updated!';
					$response['metal_group'] = $metal_group;
					$response['metal_group_id'] = $metal_group_id;
					$response['making_charge_field'] = ($enableMakingChargeGD) ? 'Enabled' : 'Not Enabled';
					$response['making_charge_unit'] = $MakingChargeUnitGD;
					$response['wastage_charge_field'] = ($enableWastageChargeGD) ? 'Enabled' : 'Not Enabled';
					$response['wastage_charge_unit'] = $WastageChargeUnitGD;
				} else {
					$response = array(
						'status' => false,
						'message' => 'Not updated!'
					);
				}
				echo json_encode($response);
			} else {
				$response = array(
					'status' => false,
					'message' => $errors
				);
				echo json_encode($response);
			}
		}

		// Metal Group Delete Process
		$metalGroupDeleteParam = isset($_POST['metalGroupDeleteParam']) ? sanitize_text_field($_POST['metalGroupDeleteParam']) : '';
		if ($metalGroupDeleteParam) {
			$metal_id = isset($_POST['metal_id']) ? sanitize_text_field($_POST['metal_id']) : '';
			$metal_group = isset($_POST['metal_group']) ? sanitize_text_field($_POST['metal_group']) : '';
			if (!empty($metal_id) && !empty($metal_group)) {
				//$taxonomy = wc_attribute_taxonomy_name(strtolower(str_replace(' ', '_',$metal_group)));
				//$terms = get_terms($taxonomy);
				//$response['terms'] = $terms;
				//if(count($terms) == 0){
				try {

					$deleted_group = $wpdb->delete($wpdb->prefix . 'its_jp_price_metal_groups', array('id' => $metal_id), array('%d'));
				} catch (Exception $e) {
					$error = $e->getMessage();
				}
				if (empty($error) && $deleted_group) {
					$response['status'] = true;

					$response['message'] = 'Metal Group Deleted';
				} else {
					$response['status'] = false;

					$response['message'] = 'Since ' . $metal_group . ' is having some metal names, this metal Group is not Deleted.';
				}

				//}

			}
			echo json_encode($response);
		}



		// Metal Name Form Processing
		$metalNameParam = isset($_POST['metalNameParam']) ? sanitize_text_field($_POST['metalNameParam']) : '';
		$metalNameEditForm = isset($_POST['metalNameEditForm']) ? sanitize_text_field($_POST['metalNameEditForm']) : '';
		$metal_table = $wpdb->prefix . "its_jp_price_settings";
		if ($metalNameParam) {

			$metal_name = sanitize_text_field($_POST['metal_name']);
			$errors = '';

			if (empty($metal_name)) {
				$errors .= 'Metal Name is required.<br>';
			} else if ($this->check_field_exist($metal_table, 'metal_name', $metal_name)) {
				$errors .= $metal_name . ' already exist.<br>';
			}
			$metal_display_name = sanitize_text_field($_POST['metal_display_name']);
			if (empty($metal_display_name)) {
				$errors .= 'Metal Display Name is required.<br>';
			} else if ($this->check_field_exist($metal_table, 'metal_display_name', $metal_display_name)) {
				$errors .= $metal_display_name . ' already exist.<br>';
			}
			$metal_group = sanitize_text_field($_POST['metal_group']);
			$query = "SELECT id FROM " . $wpdb->prefix . "its_jp_price_metal_groups where metal_group='" . $metal_group . "'";

			$result = $wpdb->get_results($query);

			$metal_price = sanitize_text_field($_POST['metal_price_per_gram']);
			if (empty($metal_price)) {
				$errors .= 'Metal Price is required.<br>';
			}

			if (!$errors) {
				$wpdb->insert($wpdb->prefix . 'its_jp_price_settings', array(
					'metal_name' => $metal_name,
					'metal_display_name' => $metal_display_name,
					'metal_group_id' => $result[0]->id,
					'amount' => $metal_price

				));
				$row_id = $wpdb->insert_id;
				if ($row_id) {

					$create_term = $this->createTerm($metal_name, str_replace(' ', '_', $metal_name), strtolower(str_replace(' ', '_',$metal_group)));
				}
				if ($row_id && $create_term) {
					$serial_no = $wpdb->get_var("SELECT COUNT(*) FROM $metal_table");
					$response = array(
						'status' => true,
						'message' => $metal_name . ' metal added!',
						'metal_name' => $metal_name,
						'metal_display_name' => $metal_display_name,
						'metal_group_id' => $result[0]->id,
						'amount' => $metal_price,
						'metal_group' => $metal_group,
						'serial_no' => $serial_no,
						'metal_id' => $row_id,
						'activated' => ($this->activated) ? true : false,
						'currency' => get_woocommerce_currency_symbol()
					);
				} else {
					$response = array(
						'status' => false,
						'message' => $metal_name . ' metal not added!'
					);
				}
				echo json_encode($response);
			} else {
				$response = array(
					'status' => false,
					'message' => $errors
				);
				echo json_encode($response);
			}
		}
		if ($metalNameEditForm) {
			$metal_id = isset($_REQUEST['metal_id']) ? sanitize_text_field($_REQUEST['metal_id']) : "";
			$metal_name_exist = $wpdb->get_results($wpdb->prepare('SELECT metal_name from ' . $metal_table . ' where id != %d', $metal_id));
			foreach ($metal_name_exist as $key => $values) {
				$existed_metals[] = $values->metal_name;
			}




			$metal_name = sanitize_text_field($_POST['metal_name']);
			$errors = '';

			if (empty($metal_name)) {
				$errors .= 'Metal Name is required.<br>';
			}
			if (in_array($metal_name, $existed_metals)) {
				$errors .= $metal_name . ' is already exist!';
			}
			$metal_display_name = sanitize_text_field($_POST['metal_display_name']);
			if (empty($metal_display_name)) {
				$errors .= 'Metal Display Name is required.<br>';
			}
			$metal_group = sanitize_text_field($_POST['metal_group']);
			$query = "SELECT id FROM " . $wpdb->prefix . "its_jp_price_metal_groups where metal_group='" . $metal_group . "'";

			$result = $wpdb->get_results($query);

			$metal_price = sanitize_text_field($_POST['metal_price_per_gram']);
			if (empty($metal_price)) {
				$errors .= 'Metal Price is required.<br>';
			}

			if (!$errors) {
				$updated = $wpdb->update(
					$wpdb->prefix . 'its_jp_price_settings',
					array(
						'metal_name' => $metal_name,
						'metal_display_name' => $metal_display_name,
						'metal_group_id' => $result[0]->id,
						'amount' => $metal_price

					),
					array(
						'id' => $metal_id

					),
					array('%s', '%s', '%d', '%f'),
					array('%d')
				);

				if ($updated) {

					$create_term = $this->createTerm($metal_name, str_replace(' ', '_', $metal_name), $metal_group);
				}
				if ($updated && $create_term) {

					$response = array(
						'status' => true,
						'message' => 'Updated!',
						'metal_name' => $metal_name,
						'metal_display_name' => $metal_display_name,
						'metal_group_id' => $result[0]->id,
						'amount' => $metal_price,
						'metal_group' => $metal_group,

						'metal_id' => $metal_id,
						'activated' => ($this->activated) ? true : false,
						'currency' => get_woocommerce_currency_symbol()
					);
				} else {
					$response = array(
						'status' => false,
						'message' => 'Not updated!'
					);
				}
				echo json_encode($response);
			} else {
				$response = array(
					'status' => false,
					'message' => $errors
				);
				echo json_encode($response);
			}
		}

		// Saving data from Discount settings form
		if (isset($_POST['its_settings_discount_form'])){
			if(update_option('itsjp-discount',$_POST)){
			/*
			Array
(
    [allowDiscountOnMetals] => 1
    [discountRateOnMetals] => 3
    [allowDiscountOnMakingCharge] => 1
    [discountRateOnMakingCharge] => 4
    [allowDiscountOnWastageCharge] => 1
    [discountRateOnWastageCharge] => 4
    [enableFlatDiscount] => 1
    [flatDiscountAmount] => Array
        (
            [0] => 500
            [1] => 1000
            [2] => 1500
        )

    [minimumSalePrice] => Array
        (
            [0] => 30000
            [1] => 35001
            [2] => 40001
        )

    [maximumSalePrice] => Array
        (
            [0] => 35000
            [1] => 40000
            [2] => 45000
        )

    [allowDiscountOn] => Array
        (
            [14_kt_gold] => 1
            [18_kt_gold] => 1
            [20_kt_gold] => 1
            [22_kt_gold] => 1
        )

    [discountRateOn] => Array
        (
            [14_kt_gold] => 3
            [18_kt_gold] => 2
            [20_kt_gold] => 2
            [22_kt_gold] => 2
        )

    [its_settings_discount_form] => its_settings_discount_form
    [action] => admin_ajax_request
)

			*/
				$response = array(
					'status' => true, 
					'message' => 'Settings saved.',
					
				);

			} else {
				$response = array('status' => false, 'message' => 'Not saved.');

			}
			echo json_encode($response);
			

		}

		// Saving data from Price Breakup settings page
		if(isset($_POST['priceBreakupSettings'])){
			if(update_option('itsjp-pricebreakup-settings',$_POST)){
				$response = array(
					'status' => true, 
					'message' => 'Settings saved.',
					
				);

			} else {
				$response = array('status' => false, 'message' => 'Not saved.');

			}
			echo json_encode($response);

		}





		wp_die();
	} //handle ajax request function ends here



	/**
	 * Create new fields for variations
	 *
	 */
	function variation_settings_fields($loop, $variation_data, $variation)
	{

		global $wpdb;
		$metal_groups = $wpdb->get_results("SELECT * FROM " . $wpdb->prefix . "its_jp_price_metal_groups");
		$checkbox_value = get_post_meta($variation->ID, 'is_jewellery_product', true);


		woocommerce_wp_checkbox(
			array(
				'id'            => 'is_jewellery_product[' . $variation->ID . ']',
				'label'         => __(' Is Jewellery Product', 'jewellery-price'),
				'desc_tip'    => 'true',
				'description'   => __('Check me!', 'jewellery-price'),
				'value'         => ($checkbox_value) ? $checkbox_value : 'yes' ,
			)
		);

		foreach ($metal_groups as $key => $value) {
			$metal_group = strtolower($value->metal_group);
			$metals = $wpdb->get_results($wpdb->prepare("SELECT * FROM " . $wpdb->prefix . "its_jp_price_settings where metal_group_id=%d", $value->id));
			$metal_attr = get_post_meta($variation->ID, 'attribute_pa_'.str_replace(' ', '_', $metal_group),true);
			$select_id = 'its_jp_' . str_replace(' ', '_', $metal_group) . '_types';

			$selected_value = get_post_meta($variation->ID, $select_id, true); 
			foreach ($metals as $key => $value1) {
				$metal_options[$value1->metal_name] = $value1->metal_name;
				$compare_attr = strtolower(str_replace(' ','_',$value1->metal_name));
				if($metal_attr == $compare_attr){
					$selected_attr = $value1->metal_name;
				}
			}
			
			


			$select_label = ucfirst($metal_group);

			woocommerce_wp_select(
				array(
					'id'          => $select_id . "[" . $variation->ID . "]",
					'value'       => ($selected_value) ? $selected_value : $selected_attr,
					'label'       => __($select_label, 'jewellery-price'),
					'options'     => $metal_options,
					'desc_tip'    => 'true',
					'description' => __('Select a ' . $select_label . ' metal type!', 'jewellery-price'),
					'wrapper_class' => 'form-row form-row-first'

				)
			);
			$metal_options = array();
			$input_id = 'its_jp_' . str_replace(' ', '_', $metal_group) . '_weight';
			$input_label =  ucfirst($metal_group) . ' Weight in gram';
			woocommerce_wp_text_input(
				array(
					'id'          => $input_id . "[" . $variation->ID . "]",
					'label'       => __($input_label, 'jewellery-price'),
					'placeholder' => '',
					'desc_tip'    => 'true',
					'description' => __('Enter the ' . $input_label . ' here.', 'jewellery-price'),
					'value'       => get_post_meta($variation->ID, $input_id, true),
					'wrapper_class' => 'form-row form-row-last'

				)
			);
			if($value->making_charge_field):
				switch($value->making_charge_unit){
					case 'gram':
						$making_charge_label = ucfirst($metal_group) . ' Making Charge in Rs. per gram';
						$making_charge_desc = 'Enter the making charge in rupees per gram here.';
						break;
					case 'percentage':
						$making_charge_label = ucfirst($metal_group) . ' Making Charge (%)';
						$making_charge_desc = 'Enter the percentage of the making charge. (eg. 5%, 10%)';

						break;
	
				}
			$making_charge_id = 'its_jp_' . str_replace(' ', '_', $metal_group) . '_making_charge';
			woocommerce_wp_text_input(
				array(
					'id'          => $making_charge_id . "[" . $variation->ID . "]",
					'label'       => __($making_charge_label, 'jewellery-price'),
					'placeholder' => '',
					'desc_tip'    => 'true',
					'description' => __($making_charge_desc, 'jewellery-price'),
					'value'       => get_post_meta($variation->ID, $making_charge_id, true),
					'wrapper_class' => 'form-row form-row-first'

				)
			);
		endif;
			if($value->wastage_charge_field):
				switch($value->wastage_charge_unit){
					case 'gram':
						$wastage_charge_label = ucfirst($metal_group) . ' Wastage Charge in Rs. per gram';
						$wastage_charge_desc = 'Enter the wastage charge in rupees per gram here.';
						break;
					case 'percentage':
						$wastage_charge_label = ucfirst($metal_group) . ' Wastage Charge (%)';
						$wastage_charge_desc = 'Enter the percentage of the wastage charge. (eg. 5%, 10%)';

						break;
	
				}
			$wastage_charge_id = 'its_jp_' . str_replace(' ', '_', $metal_group) . '_wastage_charge';
			$wastage_charge_label = ucfirst($metal_group) . ' Wastage Charge (%)';
			woocommerce_wp_text_input(
				array(
					'id'          => $wastage_charge_id . "[" . $variation->ID . "]",
					'label'       => __($wastage_charge_label, 'jewellery-price'),
					'placeholder' => '',
					'desc_tip'    => 'true',
					'description' => __($wastage_charge_desc, 'jewellery-price'),
					'value'       => get_post_meta($variation->ID, $wastage_charge_id, true),
					'wrapper_class' => 'form-row form-row-last'

				)
			);
		endif;
		}



		woocommerce_wp_text_input(
			array(
				'id'          => 'its_jp_pearl_cost[' . $variation->ID . ']',
				'label'       => __('Pearl Cost', 'jewellery-price'),
				'placeholder' => '',
				'desc_tip'    => 'true',
				'description' => __('Enter the Pearl cost.', 'jewellery-price'),
				'value'       => get_post_meta($variation->ID, 'its_jp_pearl_cost', true),
				'wrapper_class' => 'form-row form-row-first'

			)
		);
		woocommerce_wp_text_input(
			array(
				'id'          => 'its_jp_extra_cost[' . $variation->ID . ']',
				'label'       => __('Extra Cost', 'jewellery-price'),
				'placeholder' => '',
				'desc_tip'    => 'true',
				'description' => __('Enter the Extra cost.', 'jewellery-price'),
				'value'       => get_post_meta($variation->ID, 'its_jp_extra_cost', true),
				'wrapper_class' => 'form-row form-row-last'

			)
		);
		woocommerce_wp_text_input(
			array(
				'id'          => 'its_jp_other_stone_cost[' . $variation->ID . ']',
				'label'       => __('Other Stone Cost', 'jewellery-price'),
				'placeholder' => '',
				'desc_tip'    => 'true',
				'description' => __('Enter the other stone cost.', 'jewellery-price'),
				'value'       => get_post_meta($variation->ID, 'its_jp_other_stone_cost', true),
				'wrapper_class' => 'form-row form-row-first'

			)
		);

		woocommerce_wp_text_input(
			array(
				'id'          => 'its_jp_extra_fee[' . $variation->ID . ']',
				'label'       => __('Extra fee', 'jewellery-price'),
				'placeholder' => '',
				'desc_tip'    => 'true',
				'description' => __('Enter the extra fee here.', 'jewellery-price'),
				'value'       => get_post_meta($variation->ID, 'its_jp_extra_fee', true),
				'wrapper_class' => 'form-row form-row-last'

			)
		);
	}

	/**
	 * Save new fields for variations
	 *
	 */
	function save_variation_settings_fields($post_id)
	{
		global $wpdb;
		$metal_groups = $wpdb->get_results("SELECT * FROM " . $wpdb->prefix . "its_jp_price_metal_groups");
		update_post_meta($post_id, 'is_jewellery_product', sanitize_text_field($_POST['is_jewellery_product'][$post_id]));
		foreach ($metal_groups as $key => $value) {
			$metal_group = strtolower($value->metal_group);

			$select_id = 'its_jp_' . str_replace(' ', '_', $metal_group) . '_types';
			$input_id = 'its_jp_' . str_replace(' ', '_', $metal_group) . '_weight';
			$making_charge_id = 'its_jp_' . str_replace(' ', '_', $metal_group) . '_making_charge';
			$wastage_charge_id = 'its_jp_' . str_replace(' ', '_', $metal_group) . '_wastage_charge';
			update_post_meta($post_id, $select_id, sanitize_text_field($_POST[$select_id][$post_id]));
			update_post_meta($post_id, $input_id, sanitize_text_field($_POST[$input_id][$post_id]));
			update_post_meta($post_id, $making_charge_id, sanitize_text_field($_POST[$making_charge_id][$post_id]));
			update_post_meta($post_id, $wastage_charge_id, sanitize_text_field($_POST[$wastage_charge_id][$post_id]));
		}


		update_post_meta($post_id, 'its_jp_pearl_cost', sanitize_text_field($_POST['its_jp_pearl_cost'][$post_id]));
		update_post_meta($post_id, 'its_jp_extra_cost', sanitize_text_field($_POST['its_jp_extra_cost'][$post_id]));
		update_post_meta($post_id, 'its_jp_other_stone_cost', sanitize_text_field($_POST['its_jp_other_stone_cost'][$post_id]));

		update_post_meta($post_id, 'its_jp_extra_fee', sanitize_text_field($_POST['its_jp_extra_fee'][$post_id]));
		$_product = wc_get_product($post_id);

		$this->product_price_calculation($_product);
	}


	/**
	 * Add custom fields for variations
	 *
	 */
	function load_variation_settings_fields($variations)
	{

		// duplicate the line for each field
		$variations['text_field'] = get_post_meta($variations['variation_id'], '_text_field', true);

		return $variations;
	}
	public function check_license()
	{
		require_once(JEWELLERY_PRICE_PLUGIN_PATH . "includes/license.php");
		return $itsjp_activated;
	}

	// Helper Functions
	public function createAttribute(string $attributeName, string $attributeSlug)
	{
		delete_transient('wc_attribute_taxonomies');
		\WC_Cache_Helper::incr_cache_prefix('woocommerce-attributes');

		$attributeLabels = wp_list_pluck(wc_get_attribute_taxonomies(), 'attribute_label', 'attribute_name');
		$attributeWCName = array_search($attributeSlug, $attributeLabels, TRUE);

		if (!$attributeWCName) {
			$attributeWCName = wc_sanitize_taxonomy_name($attributeSlug);
		}

		$attributeId = wc_attribute_taxonomy_id_by_name($attributeWCName);
		if (!$attributeId) {
			$taxonomyName = wc_attribute_taxonomy_name($attributeWCName);
			unregister_taxonomy($taxonomyName);
			$attributeId = wc_create_attribute(array(
				'name' => $attributeName,
				'slug' => $attributeSlug,
				'type' => 'select',
				'order_by' => 'menu_order',
				'has_archives' => 0,
			));

			register_taxonomy($taxonomyName, apply_filters('woocommerce_taxonomy_objects_' . $taxonomyName, array(
				'product'
			)), apply_filters('woocommerce_taxonomy_args_' . $taxonomyName, array(
				'labels' => array(
					'name' => $attributeSlug,
				),
				'hierarchical' => FALSE,
				'show_ui' => FALSE,
				'query_var' => TRUE,
				'rewrite' => FALSE,
			)));
		}

		return wc_get_attribute($attributeId);
	}

	public function createTerm(string $termName, string $termSlug, string $taxonomy, int $order = 0)
	{
		$taxonomy = wc_attribute_taxonomy_name($taxonomy);

		if (!$term = get_term_by('slug', $termSlug, $taxonomy)) {
			$term = wp_insert_term($termName, $taxonomy, array(
				'slug' => $termSlug,
			));
			$term = get_term_by('id', $term['term_id'], $taxonomy);
			if ($term) {
				update_term_meta($term->term_id, 'order', $order);
			}
		}

		return $term;
	}
	
	public function check_field_exist($table, $column, $value){
		global $wpdb;
		$value_exist = $wpdb->get_var($wpdb->prepare("SELECT $column from $table where $column = %s",$value));
		if($value_exist){
			return $value_exist;
		} else {
			return false;
		}


	}

	// Product price calculation based on metal price 
	public function product_price_calculation($_product){
		global $wpdb;
		global $current_user;
		$metal_groups_existed = $wpdb->get_results("SELECT * FROM " . $wpdb->prefix . "its_jp_price_metal_groups");
		$is_jewellery_product 	= get_post_meta($_product->get_id(), 'is_jewellery_product', true);
		if($is_jewellery_product == 'yes'){

			$metals = $wpdb->get_results("SELECT * FROM " . $wpdb->prefix . "its_jp_price_settings");
					$metal_price = array();
					foreach ($metals as $key => $value) {
						$m_name = $value->metal_name;
						$m_amount = $value->amount;
						$metal_price[$m_name] = (float)$m_amount;
					}
	
	
							foreach ($metal_groups_existed as $key => $value) {
								$metal_group = strtolower($value->metal_group);
	
								$select_id = 'its_jp_' . str_replace(' ', '_', $metal_group) . '_types';
								$input_id = 'its_jp_' . str_replace(' ', '_', $metal_group) . '_weight';
								$making_charge_id = 'its_jp_' . str_replace(' ', '_', $metal_group) . '_making_charge';
								$wastage_charge_id = 'its_jp_' . str_replace(' ', '_', $metal_group) . '_wastage_charge';
	
								$metal_type	= get_post_meta($_product->get_id(), $select_id, true);
								$metal_weight	= (float)get_post_meta($_product->get_id(), $input_id, true);
								$making_charge = (float)get_post_meta($_product->get_id(), $making_charge_id, true);
								$wastage_charge = (float)get_post_meta($_product->get_id(), $wastage_charge_id, true);
								if($making_charge){
	
									switch($value->making_charge_unit){
										case 'gram':
											$making_charge_amount = $making_charge * $metal_weight;
											break;
										case 'percentage':
											$making_charge_amount = ($making_charge / 100) * $metal_price[$metal_type] * $metal_weight;
											break;								
		
									}
								} else {
									$making_charge_amount = 0;
								}
								if($wastage_charge){
	
									switch($value->wastage_charge_unit){
										case 'gram':
											$wastage_charge_amount = $wastage_charge * $metal_weight;
											break;
										case 'percentage':
											$wastage_charge_amount = ($wastage_charge / 100) * $metal_price[$metal_type] * $metal_weight;
											break;								
		
									}
								} else {
									$wastage_charge_amount = 0;
								}
								$metal_total[$metal_group] = ($metal_price[$metal_type] * $metal_weight) + $making_charge_amount + $wastage_charge_amount;
							}
	
							$its_jp_pearl_cost	= (float)get_post_meta($_product->get_id(), 'its_jp_pearl_cost', true);
							$its_jp_extra_cost	= (float)get_post_meta($_product->get_id(), 'its_jp_extra_cost', true);
							$its_jp_other_stone_cost	= (float)get_post_meta($_product->get_id(), 'its_jp_other_stone_cost', true);
							$its_jp_extra_fee	= (float)get_post_meta($_product->get_id(), 'its_jp_extra_fee', true);
	
	
							$final_price = array_sum($metal_total) + $its_jp_pearl_cost + $its_jp_extra_cost + $its_jp_other_stone_cost + $its_jp_extra_fee;
	
							$final_price = (HAJMILAF == 8564) ? ($final_price + (($final_price * 3) / 100)) : 0;
	
	
	
	
							$wpdb->insert($wpdb->prefix . 'its_jp_product_price_logs', array(
								'product_id' => $_product->get_id(),
								'product_name' => $_product->get_name(),
								'old_amount' => get_post_meta($_product->get_id(), '_price', true),
								'new_amount' => round($final_price),
								'updated_user' => $current_user->user_login
	
	
							));
	
							update_post_meta($_product->get_id(), '_price',         round($final_price));
							update_post_meta($_product->get_id(), '_regular_price', round($final_price));
		}
						
						

	}
} // Closing of class