<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       ifelsetech.com
 * @since      1.0.0
 *
 * @package    Its_Price_Breakup
 * @subpackage Its_Price_Breakup/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Its_Price_Breakup
 * @subpackage Its_Price_Breakup/includes
 * @author     ifelse <info@ifelsetech.com>
 */
class Its_Price_Breakup {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Its_Price_Breakup_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	 protected $activated;
	public function __construct() {
		if ( defined( 'ITS_PRICE_BREAKUP_VERSION' ) ) {
			$this->version = ITS_PRICE_BREAKUP_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->plugin_name = 'its-price-breakup';
		$this->activated = $this->activate_product();

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();
		
	
	

	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Its_Price_Breakup_Loader. Orchestrates the hooks of the plugin.
	 * - Its_Price_Breakup_i18n. Defines internationalization functionality.
	 * - Its_Price_Breakup_Admin. Defines all hooks for the admin area.
	 * - Its_Price_Breakup_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {
	   
	    
	    

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-its-price-breakup-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-its-price-breakup-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/class-its-price-breakup-admin.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'public/class-its-price-breakup-public.php';

		$this->loader = new Its_Price_Breakup_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Its_Price_Breakup_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new Its_Price_Breakup_i18n();

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Its_Price_Breakup_Admin( $this->get_plugin_name(), $this->get_version(), $this->get_activated() );

		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );
        $this->loader->add_action('admin_menu', $plugin_admin, 'its_pb_admin_menu',20);
	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

		$plugin_public = new Its_Price_Breakup_Public( $this->get_plugin_name(), $this->get_version(), $this->get_activated() );

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );
		$this->loader->add_action('woocommerce_product_after_tabs',$plugin_public,'its_variable_product_price_breakup',10);
		$this->loader->add_action('wp_ajax_its_variable_product_price_breakup_ajax_request',$plugin_public, 'its_variable_product_price_breakup_ajax_function' );
		$this->loader->add_action('wp_ajax_nopriv_its_variable_product_price_breakup_ajax_request',$plugin_public, 'its_variable_product_price_breakup_ajax_function' );
		$this->loader->add_action('woocommerce_product_after_tabs',$plugin_public,'its_simple_product_price_breakup',10);

	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Its_Price_Breakup_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}
	public function get_activated() {
		return $this->activated;
	}
	
	public function activate_product(){
	    require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/itspb_license.php';
	    $licensekey = "";
        $localkey = "";
        $itspb_activated="";


$handle = fopen(ITS_PRICE_BREAKUP_PATH. "includes/license.txt","r");
if($handle){
    $count = 0;
    while(($line = fgets($handle)) !== false){
        // process the line read
        if($count == 0){
            $licensekey = trim($line);
        } else if ($count == 1){ 
            $localkey = trim($line);
            break; 
        }
        $count++;


    }
    fclose($handle);
} else {
    die("Could not read license file. Please contact support.");
}

// Validate the license key information
$results = itspb_check_license($licensekey, $localkey);

// Raw output of results for debugging purpose
//echo '<textarea cols="100" rows="20">' . print_r($results, true) . '</textarea>';
if($results['addons']){

	$tempresults = explode("|",$results["addons"]);
	foreach ($tempresults AS $tempresult) {
	  $tempresults2 = explode(";",$tempresult);
	  $temparr = array();
	 
	  foreach ($tempresults2 AS $tempresult) {
	  $tempresults3 = explode("=",$tempresult);
		$temparr[$tempresults3[0]] = $tempresults3[1];
	  }
	 
	  $addons[] = $temparr;
	}
}
//print_r($addons);
//echo $addons[0]['name'];
//echo $addons[0]['status'];

// Interpret response
if($results['status']=='Active'){

	$days_active = date("Y-m-d") <= $results['nextduedate'];
}
//var_dump($days_active);

switch ($results['status']) {
    case "Active":
        // get new local key and save it somewhere
        $itspb_activated = ($days_active and $addons[0]['name']=='ITS Price Breakup' and $addons[0]['status']=='Active') ? true : false;
       // var_dump($itspb_activated);
        $localkeydata =str_replace(' ','',preg_replace('/\s+/',' ',$results['localkey'])) ;
        $handle = fopen(ITS_PRICE_BREAKUP_PATH. "includes/license.txt","r");
if($handle){
    $count = 0;
    while(($line = fgets($handle)) !== false){
        // process the line read
        if($count == 0){
            $licensekey = trim($line);
            break;
        }
        $count++;


    }
    fclose($handle);
    if(isset($results['localkey'])){

        $textfile = fopen(ITS_PRICE_BREAKUP_PATH. "includes/license.txt","w") or die("Unable to open file!");
                                    $contents = $licensekey."\n".$localkeydata."\n";
                                    fwrite($textfile,$contents);
                                    fclose($textfile);
    }
} else {
    die("Could not read license file. Please contact support.");
}
        break;
    case "Invalid":
       // die("License key is Invalid");
       $itspb_activated = false;
        break;
    case "Expired":
       // die("License key is Expired");
       $itspb_activated = false;
        break;
    case "Suspended":
       // die("License key is Suspended");
       $itspb_activated = false;
        break;
    default:
      //  die("Invalid Response");
      $itspb_activated = false;
        break;
}
	    return $itspb_activated;
	    
	}

}
