<?php
/**
 * Fired during plugin activation
 *
 * @link       ifelsetech.com
 * @since      1.0.0
 *
 * @package    Jewellery_Price
 * @subpackage Jewellery_Price/includes
 */
/**
 * Fired during plugin activation.
 *
 * This class defines all code necessary to run during the plugin's activation.
 *
 * @since      1.0.0
 * @package    Jewellery_Price
 * @subpackage Jewellery_Price/includes
 * @author     ifelsetech <dev@ifelsetech.com>
 */
class Jewellery_Price_Activator {
	/**
	 * Short Description. (use period)
	 *
	 * Long Description.
	 *
	 * @since    1.0.0
	 */
	public static function activate() {
		   		if(get_transient( 'itsjp_after_install_notice') || get_option('itsjpp_license_key')){
						delete_transient( 'itsjp_after_install_notice');
					} else {
						set_transient( 'itsjp_after_install_notice', true);
					}
		global $wpdb;
		//Create table in database
		$its_jp_metal_groups = $wpdb->prefix."its_jp_price_metal_groups";
		$table_exists = $wpdb->get_var("SHOW TABLES LIKE ".$its_jp_metal_groups);
		if($table_exists !== $its_jp_metal_groups){
			$table_query = "CREATE TABLE ".$its_jp_metal_groups."(
				`id` int(11) NOT NULL AUTO_INCREMENT,
				`metal_group` varchar(150) DEFAULT NULL,
				`making_charge_field` tinyint(1) DEFAULT 0,
				`making_charge_unit` varchar(150) DEFAULT NULL,
				`wastage_charge_field` tinyint(1) DEFAULT 0,
				`wastage_charge_unit` varchar(150) DEFAULT NULL,				
				`created_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
				PRIMARY KEY(`id`)
			) ENGINE=InnoDB DEFAULT CHARSET=latin1";
			require_once(ABSPATH.'wp-admin/includes/upgrade.php');
			dbDelta($table_query);
		} // end of if condition
		$its_jp_price_settings = $wpdb->prefix."its_jp_price_settings";
		$table_exists = $wpdb->get_var("SHOW TABLES LIKE ".$its_jp_price_settings);
		if($table_exists !== $its_jp_price_settings){
			$table_query = "CREATE TABLE ".$its_jp_price_settings."(
				`id` int(11) NOT NULL AUTO_INCREMENT,
				`metal_name` varchar(150) DEFAULT NULL,
				`metal_display_name` varchar(255) DEFAULT NULL,
				`metal_group_id` int(11) NOT NULL,
				`amount` int(20) DEFAULT NULL,
				`created_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
				PRIMARY KEY(`id`),
				FOREIGN KEY (`metal_group_id`) REFERENCES `".$wpdb->prefix."its_jp_price_metal_groups` (`id`)
			) ENGINE=InnoDB DEFAULT CHARSET=latin1";
			require_once(ABSPATH.'wp-admin/includes/upgrade.php');
			dbDelta($table_query);
		} // end of if condition
		$its_jp_metal_price_logs = $wpdb->prefix."its_jp_metal_price_logs";
		$table_exists2 = $wpdb->get_var("SHOW TABLES LIKE ".$its_jp_metal_price_logs);
		if($table_exists2 !== $its_jp_metal_price_logs){
			$table_query2 = "CREATE TABLE ".$its_jp_metal_price_logs."(
				`id` int(11) NOT NULL AUTO_INCREMENT,
				`metal_name` varchar(150) DEFAULT NULL,
				`old_amount` int(20) DEFAULT NULL,
				`new_amount` int(20) DEFAULT NULL,
				`updated_user` varchar(150) DEFAULT NULL,
				`created_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
				PRIMARY KEY(`id`)
			) ENGINE=InnoDB DEFAULT CHARSET=latin1";
			require_once(ABSPATH.'wp-admin/includes/upgrade.php');
			dbDelta($table_query2);
		}
		$its_jp_product_price_logs = $wpdb->prefix."its_jp_product_price_logs";
		$table_exists2 = $wpdb->get_var("SHOW TABLES LIKE ".$its_jp_product_price_logs);
		if($table_exists2 !== $its_jp_product_price_logs){
			$table_query2 = "CREATE TABLE ".$its_jp_product_price_logs."(
				`id` int(11) NOT NULL AUTO_INCREMENT,
				`product_id` int(11) NOT NULL,
				`product_name` varchar(150) DEFAULT NULL,
				`old_amount` int(20) DEFAULT NULL,
				`new_amount` int(20) DEFAULT NULL,
				`updated_user` varchar(150) DEFAULT NULL,
				`updated_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
				PRIMARY KEY(`id`)
			) ENGINE=InnoDB DEFAULT CHARSET=latin1";
			require_once(ABSPATH.'wp-admin/includes/upgrade.php');
			dbDelta($table_query2);
		}
		$cu = wp_get_current_user();
		if ($cu->has_cap('edit_users')) {
			$countries_obj   = new WC_Countries();
			$contact_name = $cu->user_firstname . ' ' . $cu->user_lastname;
			$company_name = get_bloginfo( 'name' );
			$name = get_bloginfo( 'name' );
			$site_url = site_url();
			$email = $cu->user_email;
			$timezone = wp_timezone_string();
			$address = $countries_obj->get_base_address() . ', '.$countries_obj->get_base_address_2();
			$city = $countries_obj->get_base_city();
			$state = $countries_obj->get_base_state();
			$postcode = $countries_obj->get_base_postcode();
			$countries = $countries_obj->get_countries();
			$country = $countries[$countries_obj->get_base_country()];
			$billing_phone = get_user_meta($cu->ID,'billing_phone',true);
			$shipping_phone = get_user_meta($cu->ID,'shipping_phone',true);
			if($billing_phone && $shipping_phone){
				$phone = $billing_phone .' / '.$shipping_phone;
			} else if($billing_phone && !$shipping_phone){
				$phone = $billing_phone;
			} else if(!$billing_phone && $shipping_phone){
				$phone = $shipping_phone;
			} else {
				$phone = '';
			}
			$endpoint = 'https://ifelsetechno.com/demo/itsjp-apis/apis/customer/create.php';
			$body = [
				'name'        => $name,
				'contact_name' => $contact_name,
				'company' => $company_name,
				'site_url'  => $site_url,
				'email' => $email,
				'timezone' => $timezone,
				'address' => $address,
				'city' => $city,
				'state' => $state,
				'zip' => $postcode,
				'country' => $country,
				'phone' => $phone
			];
			$body = wp_json_encode( $body );
			$options = [
				'body'        => $body,
				'headers'     => [
					'Content-Type' => 'application/json',
				],
				'timeout'     => 60,
				'redirection' => 5,
				'blocking'    => true,
				'httpversion' => '1.0',
				'sslverify'   => true,
				'data_format' => 'body',
			];
			wp_remote_post( $endpoint, $options );
		}
	
	}  // end of the function activate()
} // end of the class
