<?php
/**
 * The public-facing functionality of the plugin.
 *
 * @link       ifelsetech.com
 * @since      1.0.0
 *
 * @package    Jewellery_Price
 * @subpackage Jewellery_Price/public
 */
/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Jewellery_Price
 * @subpackage Jewellery_Price/public
 * @author     ifelsetech <dev@ifelsetech.com>
 */
class Jewellery_Price_Public {
	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;
	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;
	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of the plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	private $activated;
	private $itsjp_pricebreakup_settings;
	public function __construct( $plugin_name, $version, $activated ) {
		$this->plugin_name = $plugin_name;
		$this->version = $version;
		$this->activated = $activated['activated'];
		$this->itsjp_pricebreakup_settings = get_option('itsjp-pricebreakup-settings',false);
	}
	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {
		wp_enqueue_style("its-jp-bootstrap", JEWELLERY_PRICE_PLUGIN_URL . 'admin/css/bootstrap.min.css', array(), $this->version, 'all');
		wp_enqueue_style( $this->plugin_name, JEWELLERY_PRICE_PLUGIN_URL . 'public/css/jewellery-price-public.css', array(), $this->version, 'all' );
	}
	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {
		wp_enqueue_script('its-bp-bootstrap', 'https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js', array('jquery'), $this->version, false);
		wp_enqueue_script('jquery');
		wp_enqueue_script( 'its-jp-public', JEWELLERY_PRICE_PLUGIN_URL . 'public/js/jewellery-price-public.js', array( 'jquery' ), $this->version, false );
		wp_localize_script(
			'its-jp-public',
			'its_jp_ajax_public',
			array(
				'ajaxurl' => admin_url('admin-ajax.php')
			)
		);
		// price breakup functionality
		$itsjp_pricebreakup_settings = get_option('itsjp-pricebreakup-settings',false);
		if(isset($itsjp_pricebreakup_settings['enablePriceBreakup']) && $itsjp_pricebreakup_settings['enablePriceBreakup'] == 1 ){
		wp_enqueue_script( 'its-price-breakup-public', plugin_dir_url( __FILE__ ) . 'js/its-price-breakup-public.js', array( 'jquery' ), $this->version, false );
		wp_localize_script(
			'its-price-breakup-public',
			'its_price_breakup_ajax_public',
			array(
				'ajaxurl' => admin_url('admin-ajax.php')
			)
		);
	}
	}
// Ajax callback function for variable product price breakup
public function its_jp_public_ajax_function(){
    global $product;
   if (isset($_REQUEST['var_id'])) {
        $id = sanitize_text_field($_REQUEST['var_id']);
            echo wp_json_encode($this->its_jp_add_info_change($id));
    } //request if end
    wp_die();
}
// Price breakup function for products
public function its_jp_add_info_change($id){
    global $product;
    global $wpdb;    
            $pid = $id;
$product_data = wc_get_product($pid);
ob_start();
$attributes = $product_data->get_variation_attributes();
$dimension_unit = get_option( 'woocommerce_dimension_unit' );
 ?>
<table>
  <tr>
    <th>WEIGHT</th>
    <td><?php echo wc_format_weight($product_data->get_weight())?></td>
  </tr>
  <tr>
    <th>DIMENSIONS</th>
    <td>
      <?php echo 'Width: '.$product_data->get_width().' '.$dimension_unit.'&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; Height: '.$product_data->get_height().' '.$dimension_unit ?>
    </td>
  </tr>
  <?php
foreach($attributes as $attribute_key => $attribute_value){
    $term = get_term_by( 'slug', $attribute_value, str_replace('attribute_','',$attribute_key) );
   ?>
  <tr>
    <th><?php echo esc_html(str_replace('-',' ',str_replace('pa_','',$term->taxonomy))) ?></th>
    <td><?php echo esc_html($term->name) ?></td>
  </tr>
  <?php
}
?>
</table>
<?php $ai_tab=ob_get_contents();
ob_get_clean();
$data['ai_tab'] = $ai_tab;
return $data;
}
// Price breakup for variable product
public function its_variable_product_price_breakup(){
    if($this->activated){
    global $product;
   if ( $product->is_type( 'variable' ) ) {
         echo "<div><p style='color: #666;font-family: Libre Franklin, Arial, Helvetica, sans-serif;font-size: .857em;font-weight: 600;margin: 0 0 15px 0;text-transform: uppercase;width: 100%;'>Price Breakup&nbsp;&nbsp;<sup style='font-size:11px;color:#81CA33;cursor:pointer;' data-bs-toggle='modal' data-bs-target='#variablebreakupresult' id='pleasewait'>Show</sup></p>";
     echo '<div style="z-index:2147483647" class="modal" tabindex="-1" id="variablebreakupresult"><div class="modal-dialog modal-lg "><div class="modal-content"><div class="modal-header"><h5 class="modal-title">Price Breakup</h5><button type="button"class="btn-close"data-bs-dismiss="modal"aria-label="Close"></button></div><div class="modal-body table-responsive" id="breakupresult"></div></div></div></div></div>';
   }
    }
}
// Ajax callback function for variable product price breakup
public function its_variable_product_price_breakup_ajax_function(){
      if($this->activated){
    global $product;
   if (isset($_REQUEST['var_id'])) {
        $id = $_REQUEST['var_id'];
            echo wp_json_encode($this->its_price_breakup($id));
    } //request if end
    wp_die();
      }
}
// Price breakup function for products
public function its_price_breakup($id){
      if($this->activated){
    global $product;
    global $wpdb;    
            $pid = $id;
            $currency_pos    = get_option('woocommerce_currency_pos');
            $currency_symbol = get_woocommerce_currency_symbol();
            $metals = $wpdb->get_results("SELECT * FROM " . $wpdb->prefix . "its_jp_price_settings");
				$metal_price = array();
				foreach ($metals as $key => $value) {
					$m_name = $value->metal_name;
					$m_amount = $value->amount;
					$metal_price[$m_name] = $m_amount;
				}
             $metal_groups = $wpdb->get_results("SELECT * FROM " . $wpdb->prefix . "its_jp_price_metal_groups");
             $response='<table class="table table-bordered border-secondary table-hover text-center">';
$response.="<thead >";
$response.="<tr>";
$response.="<th>Component</th>";
$response.="<th>Rate</th>";
$response.="<th>Approx. Weight</th>";
$response.="<th>Value</th>";
$response.="<th>Final Value</th>";
$response.="</tr>";
$response.="</thead>";
$response.="<tbody >";
$total_before_tax = array();
                        foreach ($metal_groups as $key => $value) {
                            $metal_group = strtolower($value->metal_group);
							$select_id = $input_id = $making_charge_id = $wastage_charge_id = $metal_type = $metal_weight = $making_charge = $wastage_charge = $making_charge_amount = $wastage_charge_amount = '';
                            $select_id = 'its_jp_'.str_replace(' ','_',$metal_group).'_types';
                            $input_id = 'its_jp_'.str_replace(' ','_',$metal_group).'_weight';
                            $making_charge_id = 'its_jp_'.str_replace(' ','_',$metal_group).'_making_charge';
                            $wastage_charge_id = 'its_jp_'.str_replace(' ','_',$metal_group).'_wastage_charge';
                            $metal_type	= get_post_meta($pid, $select_id, true);
                            $metal_weight	= get_post_meta($pid, $input_id, true);
                            $making_charge = get_post_meta($pid, $making_charge_id, true);
                            $wastage_charge = get_post_meta($pid, $wastage_charge_id, true);
                            if($metal_type != '' && $metal_weight !=''){
if('' !== $metal_type){                             
                            $response.="<tr>";
$response.="<td>".ucfirst($metal_type)."</td>";
$response.="<td>".wc_price($metal_price[$metal_type])."/g</td>";
$response.="<td>".$metal_weight."g</td>";
$metal_value = $metal_price[$metal_type] * $metal_weight;
$response.="<td>".wc_price($metal_value)."</td>";
$response.="<td class='text-right'>".wc_price($metal_value)."</td>";
$response.="</tr>";
}
if($making_charge){
	switch($value->making_charge_unit){
		case 'gram':
			$making_charge_amount = ($making_charge) ? $making_charge * $metal_weight : 0;
			$unit = '/g';
			break;
		case 'percentage':
			$making_charge_amount = ($making_charge) ? ($making_charge / 100) * $metal_price[$metal_type] * $metal_weight : 0;
			$unit = '%';
			break;								
	}
 $response.="<tr>";
$response.="<td>Making Charges for ".ucfirst($metal_type)."</td>";
$response.="<td>".(($unit == '%') ? $making_charge.$unit : wc_price($making_charge).$unit)."</td>";
$response.="<td>".$metal_weight."g</td>";
//$metal_mkcharge = $making_charge * $metal_weight;
$response.="<td>".wc_price($making_charge_amount)."</td>";
$response.="<td class='text-right'>".wc_price($making_charge_amount)."</td>";
$response.="</tr>";
} else {
	$making_charge_amount = 0;
}
if($wastage_charge){
	switch($value->wastage_charge_unit){
		case 'gram':
			$wastage_charge_amount =  ($wastage_charge) ? $wastage_charge * $metal_weight : 0 ;
			$unit = '/g';
			break;
		case 'percentage':
			$wastage_charge_amount = ($wastage_charge) ? ($wastage_charge / 100) * $metal_price[$metal_type] * $metal_weight : 0;
			$unit = '%';
			break;								
	}
    $response.="<tr>";
$response.="<td>Wastage Charges for ".ucfirst($metal_type)."</td>";
$response.="<td>".(($unit == '%') ? ($wastage_charge.$unit) : (wc_price($wastage_charge).$unit) ) ."</td>";
$response.="<td>".$metal_weight."g</td>";
$response.="<td>".wc_price($wastage_charge_amount)."</td>";
$response.="<td class='text-right'>".wc_price($wastage_charge_amount)."</td>";
$response.="</tr>";
} else {
	$wastage_charge_amount = 0;
}
  $total_before_tax[$metal_group] =    $metal_value +  $making_charge_amount + $wastage_charge_amount;    
                            }
                                }
	$its_jp_pearl_cost	= get_post_meta($pid, 'its_jp_pearl_cost', true);
	$its_jp_extra_cost	= get_post_meta($pid, 'its_jp_extra_cost', true);
						$its_jp_other_stone_cost	= get_post_meta($pid, 'its_jp_other_stone_cost', true);
						$its_jp_extra_fee	= get_post_meta($pid, 'its_jp_extra_fee', true);					
if($its_jp_pearl_cost){   
$response.="<tr>";
$response.="<td colspan=4>Pearl Cost</td>";
$response.="<td class='text-right'>".wc_price($its_jp_pearl_cost)."</td>";
$response.="</tr>";
}
if($its_jp_extra_cost){   
$response.="<tr>";
$response.="<td colspan=4>Extra Cost</td>";
$response.="<td class='text-right'>".wc_price($its_jp_extra_cost)."</td>";
$response.="</tr>";
}
if($its_jp_other_stone_cost){
$response.="<tr>";
$response.="<td colspan=4>Other Stone Cost</td>";
$response.="<td class='text-right'>".wc_price($its_jp_other_stone_cost)."</td>";
$response.="</tr>";
}
if($its_jp_extra_fee){
$response.="<tr>";
$response.="<td colspan=4>Additional Charges</td>";
$response.="<td class='text-right'>".wc_price($its_jp_extra_fee)."</td>";
$response.="</tr>";
}
$final_value = array_sum($total_before_tax) + (($its_jp_pearl_cost) ? $its_jp_pearl_cost : 0) + (($its_jp_extra_cost) ? $its_jp_extra_cost : 0) + (($its_jp_other_stone_cost) ? $its_jp_other_stone_cost : 0) + (($its_jp_extra_fee) ? $its_jp_extra_fee : 0);
$response.="<tr>";
$response.="<td colspan=4>Total (Without Tax)</td>";
$response.="<td class='text-right'>".wc_price($final_value)."</td>";
$response.="</tr>";
$gst = $final_value * (3/100);
$response.="<tr>";
$response.="<td colspan=4>GST 3%</td>";
$response.="<td class='text-right'>".wc_price($gst)."</td>";
$response.="</tr>";
$total = $final_value + $gst;
$response.="<tr>";
$response.="<td colspan=4>Total</td>";
$response.="<td class='text-right'>".wc_price($total)."</td>";
$response.="</tr>";
$response.="<tr>";
$response.="<th colspan=4>Rounded Total</th>";
$response.="<th class='text-right'>".wc_price(round($total))."</th>";
$response.="</tr>";
$response.="</tbody>";
$response.="<tfooter>";
$response.="</tfooter>";
$response.="</table>";
$data = array();
$data['breakup'] = $response;
return $data;
}
      }
// Price breakup for simple product
public function its_simple_product_price_breakup(){
      if($this->activated){
     global $product;
   if ( $product->is_type( 'simple' ) ) {
       $id=$product->get_id();
        echo "<div><p style='color: #666;font-family: Libre Franklin, Arial, Helvetica, sans-serif;font-size: .857em;font-weight: 600;margin: 0 0 15px 0;text-transform: uppercase;width: 100%;'>Price Breakup&nbsp;&nbsp;<sup style='font-size:11px;color:#81CA33;cursor:pointer;' data-bs-toggle='modal' data-bs-target='#simplebreakupresult'>Show</sup></p>";
     echo '<div style="z-index:2147483647" class="modal" tabindex="-1" id="simplebreakupresult"><div class="modal-dialog modal-lg"><div class="modal-content"><div class="modal-header"><h5 class="modal-title">Price Breakup</h5><button type="button"class="btn-close"data-bs-dismiss="modal"aria-label="Close"></button></div><div class="modal-body table-responsive">';
    $result = $this->its_price_breakup($id);
    echo $result['breakup'];
     echo "</div></div></div></div></div>";
}
}
}
public  function itsjp_price_breakup_shortcode($atts = [], $content = null, $tag = '' ){
	if($this->activated && isset($this->itsjp_pricebreakup_settings['enablePriceBreakup']) && $this->itsjp_pricebreakup_settings['enablePriceBreakup'] == 1 ){
		// normalize attribute keys, lowercase
	$atts = array_change_key_case( (array) $atts, CASE_LOWER );
	// override default attributes with user attributes
	$itsjp_atts = shortcode_atts(
		array(
			'show' => 'default',
		), $atts, $tag
	);
		global $product;
		$type = $product->get_type();
		$id=$product->get_id();
		ob_start();
		if($type == 'simple'){
			switch ($itsjp_atts['show']) {
				case 'default':
					# code...
					echo "<div><p style='color: #666;font-family: Libre Franklin, Arial, Helvetica, sans-serif;font-size: .857em;font-weight: 600;margin: 0 0 15px 0;text-transform: uppercase;width: 100%;'>Price Breakup&nbsp;&nbsp;<sup style='font-size:11px;color:#81CA33;cursor:pointer;' id='show-breakup-below-tab'>Show</sup></p>";
				 echo '<div id="simple-breakup-below-tab" style="display:none;">';
				$result = $this->its_price_breakup($id);
				echo $result['breakup'];
				 echo "</div>";
					break;
				case 'popup':
				$this->its_simple_product_price_breakup();
				break;
				default:
					# code...
					break;
			}
		} else if ($type == 'variable') {
			switch($itsjp_atts['show']){
				case 'default':
					echo "<div><p style='color: #666;font-family: Libre Franklin, Arial, Helvetica, sans-serif;font-size: .857em;font-weight: 600;margin: 0 0 15px 0;text-transform: uppercase;width: 100%;'>Price Breakup&nbsp;&nbsp;<sup style='font-size:11px;color:#81CA33;cursor:pointer;' id='show-breakup-below-tab'>Please wait ...</sup></p>";
     echo '<div id="simple-breakup-below-tab" ></div>'; 
		 break;
		 case 'popup':
			$this->its_variable_product_price_breakup();
			break;
			default:
			break;

			}
			 
		}
		return ob_get_clean();
	}
	return '';
}
public function itsjp_add_shortcodes(){
	add_shortcode('itsjp_price_breakup',array($this,'itsjp_price_breakup_shortcode'));
}
}